#!/usr/bin/env python

"""Tests for `django_impala_backend` package."""


import unittest

from django_impala_backend import django_impala_backend


class TestDjango_impala_backend(unittest.TestCase):
    """Tests for `django_impala_backend` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
